<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link		https://heymunky.co.uk
 * @since		1.0.0
 *
 * @package		Munky_Mm
 * @subpackage	Munky_Mm/admin
 */

class Munky_Mm_Admin_Settings {

	/**
	* The ID of this plugin.
	*
	* @since	1.0.0
	* @access	private
	* @var		string	$plugin_name	The ID of this plugin.
	*/
	private $plugin_name;

	/**
	* The version of this plugin.
	*
	* @since  1.0.0
	* @access  private
	* @var   string  $version  The current version of this plugin.
	*/
	private $version;

	/**
	* Initialize the class and set its properties.
	*
	* @since	1.0.0
	* @param	string	$plugin_name	The name of this plugin.
	* @param	string	$version		The version of this plugin.
	*/
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	* This function introduces the theme options into the 'Appearance' menu and into a top-level
	* 'Munky Menu' menu.
	*/
	public function setup_plugin_options_menu() {

		//Add the menu to the Plugins set of menu items
		add_menu_page(
			$this->plugin_name,								// The text to be displayed in the title tags of the page when the menu is selected.
			'Munky Menu',									// The text to be used for the menu.
			'administrator',								// The capability required for this menu to be displayed to the user.
			'munky-menu-settings',							// The slug name to refer to this menu by. Should be unique for this menu page
			
			array($this, 'render_settings_page_content'),	// The function to be called to output the content for this page.
				'dashicons-menu',							// The URL to the icon to be used for this menu.
				101											// The position in the menu order this item should appear.
		);

	}

	/**
	* Provides default values for the Branding Options.
	*
	* @return array
	*/
	public function default_branding_options() {

		$defaults = array(
			'brand_color'	=> 'rgba(211,90,0,1)',
			'header_text'	=> 'Munky Mobile Menu',
			'header_font'	=> '\'Hey Munky\'',
			'header_logo'	=> '',
		);

	return $defaults;

	}

	/**
	* Provides default values for the Burger Options.
	*
	* @return array
	*/
	public function default_burger_options() {

		$defaults = array(
			'burger_background_color'	=> 'rgba(211,90,0,1)',
			'burger_gradient_color'		=> 'rgba(255,107,0,1)',
			'burger_button_color'		=> 'rgba(255,255,255,1)',
			'burger_size'				=> '40',
		);

	return $defaults;

	}

	/**
	* Provides default values for the Menu Options.
	*
	* @return array
	*/
	public function default_menu_options() {

		$defaults = array(
			'menu_enable'				=> 'true',
			'menu_background_color'		=> 'rgba(255,255,255,1)',
			'menu_link_color'			=> 'rgba(211,90,0,1)',
			'icon_background_color'		=> 'rgba(232,232,232,1)',
			'icon_color'				=> 'rgba(102,102,102,1)',
			'cta_icon_one'				=> 'fa-home',
			'cta_icon_two'				=> 'fa-envelope',
			'cta_icon_three'			=> 'fa-shopping-basket',
			'cta_title_one'				=> 'Home',
			'cta_title_two'				=> 'Contact',
			'cta_title_three'			=> 'Basket',
			'cta_url_one'				=> '/',
			'cta_url_two'				=> '#',
			'cta_url_three'				=> '#',
		);

	return $defaults;

	}

	/**
	* Provides default values for Support.
	*
	* @return array
	*/
	public function default_support_options() {

		$defaults = array(
			'usage'		=> '',
		);

	return $defaults;

	}

	/**
	* Renders a simple page to display for the theme menu defined above.
	*/
	public function render_settings_page_content( $active_tab = '' ) {
	?>
		<!-- Create a header in the default WordPress 'wrap' container -->
		<div class="wrap">

			<h2><img src="<?php echo plugin_dir_url( __FILE__ ); ?>img/munky-head-alt.svg" width="100px" style="vertical-align: middle;"/><span class="mmm-settings-style"><?php _e( 'Munky Mobile Menu', 'munky-mm' ); ?></span></h2>
			<?php settings_errors(); ?>

			<?php if( isset( $_GET[ 'tab' ] ) ) {
				
				$active_tab = $_GET[ 'tab' ];
				
			} else if( $active_tab == 'burger_options' ) {
				
				$active_tab = 'burger_options';
				
			} else if( $active_tab == 'branding_options' ) {
				
				$active_tab = 'branding_options';
				
			} else if( $active_tab == 'menu_options' ) {
				
				$active_tab = 'menu_options';
				
			} else {
				
				$active_tab = 'support_options';
				
			} // end if/else ?>

			<h2 class="nav-tab-wrapper">
				<a href="?page=munky-menu-settings&tab=branding_options" class="nav-tab <?php echo $active_tab == 'branding_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Branding Options', 'munky-mm' ); ?></a>
				<a href="?page=munky-menu-settings&tab=burger_options" class="nav-tab <?php echo $active_tab == 'burger_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Burger Menu Options', 'munky-mm' ); ?></a>
				<a href="?page=munky-menu-settings&tab=menu_options" class="nav-tab <?php echo $active_tab == 'menu_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Main Menu Options', 'munky-mm' ); ?></a>
				<a href="?page=munky-menu-settings&tab=support_options" class="nav-tab <?php echo $active_tab == 'support_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Support', 'munky-mm' ); ?></a>
			</h2>

			<form method="post" action="options.php">
			<?php

			if( $active_tab == 'branding_options' ) {

				settings_fields( 'munky-menu-branding_options' );
				do_settings_sections( 'munky-menu-branding_options' );

			} else if( $active_tab == 'burger_options' ) {

				settings_fields( 'munky-menu-burger_options' );
				do_settings_sections( 'munky-menu-burger_options' );

			} else if( $active_tab == 'support_options' ) {

				settings_fields( 'munky-menu-support_options' );
				do_settings_sections( 'munky-menu-support_options' );

			} else {

				settings_fields( 'munky-menu-menu_options' );
				do_settings_sections( 'munky-menu-menu_options' );

			} // end if/else

			submit_button();

			?>
			</form>

		</div><!-- /.wrap -->
	<?php
	}


	/**
	* This function provides a simple description for the Branding Options page.
	*
	* It's called from the 'wppb-demo_initialize_theme_options' function by being passed as a parameter
	* in the add_settings_section function.
	*/
	public function branding_options_callback() {
		$options = get_option('munky-menu-branding_options');
		//var_dump($options);
		echo '<p>' . __( 'Here you can customise the menu with your own branding.', 'munky-mm' ) . '</p>';
	} // end branding_options_callback
	
	/**
	* This function provides a simple description for the Burger Options page.
	*
	* It's called from the 'wppb-demo_initialize_theme_options' function by being passed as a parameter
	* in the add_settings_section function.
	*/	
	public function burger_options_callback() {
		$options = get_option('munky-menu-burger_options');
		//var_dump($options);
		echo '<p>' . __( 'Here you can customise the burger menu.', 'munky-mm' ) . '</p>';
	} // end burger_options_callback
	
	/**
	* This function provides a simple description for the Main Menu Options page.
	*
	* It's called from the 'wppb-demo_theme_initialize_input_examples_options' function by being passed as a parameter
	* in the add_settings_section function.
	*/
	public function menu_options_callback() {
		$options = get_option('munky-menu-menu_options');
		//var_dump($options);
		echo '<p>' . __( 'Change the look of the opened menu.', 'munky-mm' ) . '</p>';
	} // end menu_options_callback	
	
	/**
	* This function provides a simple description for the Support page.
	*
	* It's called from the 'wppb-demo_theme_initialize_input_examples_options' function by being passed as a parameter
	* in the add_settings_section function.
	*/
	public function support_options_callback() {
		$options = get_option('munky-menu-support_options');
		//var_dump($options);
		echo '<p>' . __( 'Support for Munky Mobile Menu.', 'munky-mm' ) . '</p>';
	} // end support_options_callback

	/**
	* Initializes the theme's Branding options page by registering the Sections,
	* Fields, and Settings.
	*
	* This function is registered with the 'admin_init' hook.
	*/
	public function initialize_branding_options() {

		// If the theme options don't exist, create them.
		if( false == get_option( 'munky-menu-branding_options' ) ) {
			$default_array = $this->default_branding_options();
			add_option( 'munky-menu-branding_options', $default_array );
		}

		add_settings_section(
		'branding_settings_section',					// ID used to identify this section and with which to register options
		__( 'Branding Options', 'munky-mm' ),			// Title to be displayed on the administration page
		array( $this, 'branding_options_callback'),		// Callback used to render the description of the section
			'munky-menu-branding_options',				// Page on which to add this section of options
		);

		add_settings_field(
			'Brand Color',
			__( 'Brand Color', 'munky-mm' ),
			array( $this, 'brand_color_callback'),
				'munky-menu-branding_options',
				'branding_settings_section',
			array(
				__( '', 'munky-mm' ),
			)
		);
		
		add_settings_field(
			'Menu Header Logo',
			__( 'Menu Header Logo', 'munky-mm' ),
			array( $this, 'image_element_callback'),
				'munky-menu-branding_options',
				'branding_settings_section',
			array(
				__( '', 'munky-mm' ),
			)
		);

		add_settings_field(
			'Menu Header Text',
			__( 'Menu Header Text', 'munky-mm' ),
			array( $this, 'header_text_callback'),
				'munky-menu-branding_options',
				'branding_settings_section',
			array(
				__( '', 'munky-mm' ),
			)
		);

		add_settings_field(
		'Menu Header Font',
		__( 'Menu Header Font', 'munky-mm' ),
		array( $this, 'header_font_callback'),
			'munky-menu-branding_options',
			'branding_settings_section'
		);

		// Finally, we register the fields with WordPress
		register_setting(
		'munky-menu-branding_options',
		'munky-menu-branding_options',
		array( $this, 'validate_menu_options')
		);

	} // end wppb-demo_initialize_theme_options
	
	/**
	* Initializes the theme's Burger Menu options page by registering the Sections,
	* Fields, and Settings.
	*
	* This function is registered with the 'admin_init' hook.
	*/
	public function initialize_burger_options() {

		// If the theme options don't exist, create them.
		if( false == get_option( 'munky-menu-burger_options' ) ) {
			$default_array = $this->default_burger_options();
			add_option( 'munky-menu-burger_options', $default_array );
		}	

		add_settings_section(
		'burger_menu_appearance',
		__( 'Burger Menu Appearance', 'munky-mm' ),
			array( $this, 'burger_options_callback'),
			'munky-menu-burger_options'
		);

		add_settings_field(
		'Burger Background Color',
		__( 'Burger Background Color', 'munky-mm' ),
		array( $this, 'burger_background_color_callback'),
			'munky-menu-burger_options',
			'burger_menu_appearance'
		);

		add_settings_field(
		'Burger Gradient Color',
		__( 'Burger Gradient Color', 'munky-mm' ),
		array( $this, 'burger_gradient_color_callback'),
			'munky-menu-burger_options',
			'burger_menu_appearance'
		);

		add_settings_field(
		'Burger Color',
		__( 'Burger Color [ <label class="cta-icon fas fa-bars" value="fas fa-bars"></label> ]', 'munky-mm' ),
		array( $this, 'burger_button_color_callback'),
			'munky-menu-burger_options',
			'burger_menu_appearance'
		);
		
		add_settings_field(
		'Burger Menu Size',
		__( 'Burger Menu Size', 'munky-mm' ),
		array( $this, 'burger_size_callback'),
			'munky-menu-burger_options',
			'burger_menu_appearance',
		);

		// Finally, we register the fields with WordPress
		register_setting(
		'munky-menu-burger_options',
		'munky-menu-burger_options',
		array( $this, 'validate_menu_options')
		);

	} // end wppb-demo_initialize_theme_options


	/**
	* Initializes the theme's Main Menu options by registering the Sections,
	* Fields, and Settings.
	*
	* This function is registered with the 'admin_init' hook.
	*/
	public function initialize_menu_options() {
		
		//delete_option('munky-menu-menu_options');
		if( false == get_option( 'munky-menu-menu_options' ) ) {
			$default_array = $this->default_menu_options();
			update_option( 'munky-menu-menu_options', $default_array );
		} // end if

		add_settings_section(
		'menu_options_section',
		__( 'Main Menu Appearance', 'munky-mm' ),
			array( $this, 'menu_options_callback'),
			'munky-menu-menu_options'
		);

		add_settings_field(
		'Menu Background Color',
		__( 'Menu Background Color', 'munky-mm' ),
		array( $this, 'menu_background_color_callback'),
			'munky-menu-menu_options',
			'menu_options_section'
		);

		add_settings_field(
		'Menu Link Color',
		__( 'Menu Link Color', 'munky-mm' ),
		array( $this, 'menu_link_color_callback'),
			'munky-menu-menu_options',
			'menu_options_section'
		);

		add_settings_field(
		'Icon Background Color',
		__( 'Icon Background Color', 'munky-mm' ),
		array( $this, 'icon_background_color_callback'),
			'munky-menu-menu_options',
			'menu_options_section'
		);

		add_settings_field(
		'Icon Color',
		__( 'Icon Color [
			<label class="cta-icon fas fa-level-down-alt" value="fas fa-level-down-alt"></label> 
			<label class="cta-icon fas fa-level-up-alt" value="fas fa-level-up-alt"></label> 
			<label class="cta-icon fas fa-sign-out-alt fa-rotate-90" value="fa-sign-out-alt"></label> 
			<label class="cta-icon fas fa-sign-in-alt fa-rotate-270" value="fa-sign-in-alt"></label> 
			<label class="cta-icon fas fa-power-off" value="fas fa-power-off"></label> 
			<label class="cta-icon fas fa-search" value="fas fa-search"></label>
		]', 'munky-mm' ),
		array( $this, 'icon_color_callback'),
			'munky-menu-menu_options',
			'menu_options_section'
		);

		add_settings_field(
		'Call-to-Action Buttons',
		__( 'Call-to-Action Buttons', 'munky-mm' ),
		array( $this, 'cta_callback'),
			'munky-menu-menu_options',
			'menu_options_section'
		);

		register_setting(
		'munky-menu-menu_options',
		'munky-menu-menu_options',
		array( $this, 'validate_menu_options')
		);

	}
	
	public function initialize_support_options() {

		// If the theme options don't exist, create them.
		if( false == get_option( 'munky-menu-support_options' ) ) {
			$default_array = $this->default_support_options();
			add_option( 'munky-menu-support_options', $default_array );
		}

		add_settings_section(
		'support_options_section',						// ID used to identify this section and with which to register options
		__( 'Support', 'munky-mm' ),					// Title to be displayed on the administration page
		array( $this, 'support_options_callback'),		// Callback used to render the description of the section
			'munky-menu-support_options',				// Page on which to add this section of options
		);

		add_settings_field(
		'Usage',
		__( 'Usage', 'munky-mm' ),
			array( $this, 'support_usage_callback'),
			'munky-menu-support_options',
			'support_options_section',
		);

		add_settings_field(
		'Frequently Asked Questions',
		__( 'Frequently Asked Questions', 'munky-mm' ),
			array( $this, 'support_faq_callback'),
			'munky-menu-support_options',
			'support_options_section',
		);

		add_settings_field(
		'Support Information',
		__( 'Support Information', 'munky-mm' ),
			array( $this, 'support_info_callback'),
			'munky-menu-support_options',
			'support_options_section',
		);

		register_setting(
		'munky-menu-support_options',
		'munky-menu-support_options',
		array( $this, 'validate_menu_options')
		);
	}

	//Callbacks to display the various options on the settings page
	
	public function brand_color_callback() {
		
		$options = get_option( 'munky-menu-branding_options' );
		
		if( !isset( $options['brand_color'] ) ) $options['brand_color'] = 'rgba(211,90,0,1)';

			echo '<input type="text" id="brand-color-picker" class="color-picker" data-alpha-enabled="true" data-default-color="rgba(211,90,0,1)" name="munky-menu-branding_options[brand_color]" value="' . sanitize_text_field($options['brand_color']) . '"/>
				<p>Use this field to apply your main brand colour to Munky Mobile Menu.</p>';
	}
	
	public function image_element_callback() {
		
		wp_enqueue_media();
		
		$options = get_option( 'munky-menu-branding_options' );
		
			if ( $options['header_logo'] == '' ) {
				$display = 'none';
			} else {
				$display = 'block';
			}
			
		echo '<img src="' . $options['header_logo'] . '" class="image" name="munky-menu-branding_options[header_logo]" style="display: ' . $display . '; margin-bottom: 20px; max-width: 100px; max-height: 100px;"/>
		<p><span style="display: flex;margin-bottom: 10px;">
		<input type="button" value="Select image" class="button-primary" id="upload_image" style="margin-right: 10px;"/> <input type="button" value="&#xf12d" class="button-primary fas fa-eraser" id="remove_image"/>
		<input style="background: transparent; width: -webkit-fill-available; border: 0;" type="text" id="header_logo" class="image-path" name="munky-menu-branding_options[header_logo]" value="' . $options['header_logo'] . '" /></span></p>
		<input type="hidden" name="attachment_id" class="wp_attachment_id" value="" />
		<p>Change the Munky Mobile Menu logo (leave blank for none).</p>';
	}

	public function header_text_callback() {

		$options = get_option( 'munky-menu-branding_options' );
		
		if( !isset( $options['header_text'] ) ) $options['header_text'] = 'Munky Mobile Menu';

		// Render the output
		echo '<input type="text" id="header_text" name="munky-menu-branding_options[header_text]" value="' . $options['header_text'] . '" />
			<p>Change the text in the menu header (leave blank for none).</p>';

	}

	public function header_font_callback() {
		
		clearstatcache(); //file_exists is cachable. Clear the cache before calling it.
		
		//require_once plugin_dir_path( dirname( __FILE__ ) ) .  'includes/google-fonts.php';		//Disabled because Google Fonts is GDPR non-compliant but left in situ for information sake.		
		
		$custom_font_path = get_stylesheet_directory() . '/munky-mm/mmm-custom-font.json';

		$options = get_option( 'munky-menu-branding_options' );
		$background_options = get_option ( 'munky-menu-menu_options' );
		
		if( !isset( $options['header_font'] ) ) $options['header_font'] = '\'Hey Munky\'';
	
		$html = '<form>';
		$html .=	'<select id="header_font" style="width: 11.1rem;" value="' . $options['header_font'] . '" name="munky-menu-branding_options[header_font]">';
		$html .=		'<option style="display: none; font-family: ' . $options['header_font'] . ';" value="' . $options['header_font'] . '">' . __( $options['header_font'], 'munky-mm' ) . '</option>';
		$html .=		'<option disabled style="color: rgb(211,90,0); text-align: center; font-family: Arial; font-weight: 700;">- Default Fonts -</option>';
		$html .=		'<option style="font-family: \'Hey Munky\';" value="Hey Munky">' . __( 'Hey Munky', 'munky-mm' ) . '</option>';
		$html .=		'<option style="font-family: \'Arial\';" value="Arial">' . __( 'Arial', 'munky-mm' ) . '</option>';
		$html .=		'<option style="font-family: \'Calibri\';" value="Calibri">' . __( 'Calibri', 'munky-mm' ) . '</option>';
		$html .=		'<option style="font-family: \'Courier New\';" value="Courier New">' . __( 'Courier New', 'munky-mm' ) . '</option>';
		$html .=		'<option style="font-family: \'Garamond\';" value="Garamond">' . __( 'Garamond', 'munky-mm' ) . '</option>';
		$html .=		'<option style="font-family: \'Times New Roman\';" value="Times New Roman">' . __( 'Times New Roman', 'munky-mm' ) . '</option>';
		$html .=		'<option style="font-family: \'Verdana\';" value="Verdana">' . __( 'Verdana', 'munky-mm' ) . '</option>';
		
		/*$html .=		'<option disabled></option>';
		$html .=		'<option disabled style="color: rgb(211,90,0); text-align: center; font-family: Arial; font-weight: 700;">- Google Fonts -</option>';
		
		foreach( $google_fonts_items as $google_font_item ){
				
			$html .=		'<option style="font-family: \'' . $google_font_item['family'] . '\', ' . $google_font_item['category'] . ';" value="' . $google_font_item['family'] . '">' . __( $google_font_item['family'], 'munky-mm' ) . '</option>';
			//$list .= '<span>' . $google_font_item['family'] . '|</span>';
		
		}*/

		if ( file_exists( $custom_font_path )) {
			require_once plugin_dir_path( dirname( __FILE__ ) ) .  'includes/custom-fonts.php';
				
			$html .=		'<option disabled></option>';
			$html .=		'<option disabled style="color: rgb(211,90,0); text-align: center; font-family: Arial; font-weight: 700;">- Your Fonts -</option>';
			
			foreach( $custom_fonts_items as $custom_font_item ){
					
				$html .=	'<option style="font-family: \'' . $custom_font_item['family'] . '\', ' . $custom_font_item['category'] . ';" value="' . $custom_font_item['family'] . '">' . __( $custom_font_item['family'], 'munky-mm' ) . '</option>';
				//$list .= '<span>' . $custom_font_item['family'] . '|</span>';
			}
		} else {			
		}
		
		$html .=	'</select>';
		$html .= '</form>';	
		
		// Preview header logo, colour, font and text options in the Admin settings.
		$html .= '<span style="padding: 5px; background-color: ' . $background_options['menu_background_color'] . '; font-weight: 700;">';
		$html .=	'<img id="header-image-preview" style="max-width: 40px; max-height: 40px; vertical-align: middle;" src="' . $options['header_logo'] . '">';
		$html .=	'<span id="header_text_wrapper" style="color: ' . $options['brand_color'] . ';">';
		$html .=		'<label id="chosen_font" style="font-family: \'' . $options['header_font'] . '\';"> ' . $options['header_text'] . '</label>';
		$html .=	'</span>';
		$html .= '</span>';
			
		echo $html;
		//echo $list;

	} // end select_element_callback
	
	public function burger_background_color_callback() {
		
		$options = get_option( 'munky-menu-burger_options' );
		
		if( !isset( $options['burger_background_color'] ) ) $options['burger_background_color'] = 'rgba(211,90,0,1)';

			echo '<input type="text" id="burger-bgd-color-picker" class="color-picker" data-alpha-enabled="true" data-default-color-type="rgb" data-default-color="rgba(211,90,0,1)" name="munky-menu-burger_options[burger_background_color]" value="' . sanitize_text_field($options['burger_background_color']) . '"/>
				<p>Here you can choose the main background colour of the burger menu button.</p>';

	}
	
	public function burger_gradient_color_callback() {
		
		$options = get_option( 'munky-menu-burger_options' );
		
		if( !isset( $options['burger_gradient_color'] ) ) $options['burger_gradient_color'] = 'rgba(255,107,0,1)';

			echo'<input type="text" id="burger-gdt-color-picker" class="color-picker" data-alpha-enabled="true" data-default-color-type="rgb" data-default-color="rgba(255,107,0,1)" name="munky-menu-burger_options[burger_gradient_color]" value="' . sanitize_text_field($options['burger_gradient_color']) . '"/>
				<p>This is the colour of the burger menu button gradient transition to give the curved appearance.</p>';
				
	}
	
	public function burger_button_color_callback() {
		
		$options = get_option( 'munky-menu-burger_options' );
		
		if( !isset( $options['burger_button_color'] ) ) $options['burger_button_color'] = 'rgba(255,255,255,1)';

			echo '<input type="text" id="burger-btn-color-picker" class="color-picker" data-alpha-enabled="true" data-default-color="rgba(255,255,255,1)" name="munky-menu-burger_options[burger_button_color]" value="' . sanitize_text_field($options['burger_button_color']) . '"/>
				<p>This is the colour applied to the burger menu icon.</p>';

	}
	
	public function burger_size_callback() {	
		
		$options = get_option( 'munky-menu-burger_options' );
		
		if( !isset( $options['burger_size'] ) ) $options['burger_size'] = '60';
		
			$burger_font = $options['burger_size'];

			echo '<span id="current-size" class="mmm-menu" style="width: ' . $options['burger_size'] . 'px; font-size: ' . $burger_font/2 . 'px;" >
					<button id="mmm-menu-button" style="background: linear-gradient(to right, ' . $options['burger_background_color'] . ',' . $options['burger_gradient_color'] . '); color: ' . $options['burger_button_color'] . '; filter: drop-shadow(2px 4px 6px ' . $options['burger_background_color'] . ');" disabled>
					</button>
				</span>
				<label id="mmm-slider-meter" class="mmm-slider-meter" style="border-color: transparent transparent ' . $options['burger_background_color'] . ' transparent;"></label>
				<input type="range" style="width: 220px; cursor: pointer;" min="40" max="80" value="' . $options['burger_size'] . '" name="munky-menu-burger_options[burger_size]" id="burger-size"> <input type="text" id="" style="display: none;" maxlength="2" size="2" value="' . $options['burger_size'] . '">
				<p>Adjust the size of the burger menu.</p>';
	}
	
	public function menu_background_color_callback() {
		
		$options = get_option( 'munky-menu-menu_options' );
		
		if( !isset( $options['menu_background_color'] ) ) $options['menu_background_color'] = 'rgba(255,255,255,1)';

			echo '<input type="text" id="menu-bgd-color-picker" class="color-picker" data-alpha-enabled="true" data-default-color="rgba(255,255,255,1)" name="munky-menu-menu_options[menu_background_color]" value="' . sanitize_text_field($options['menu_background_color']) . '"/>';

	}
	
	public function menu_link_color_callback() {
		
		$options = get_option( 'munky-menu-menu_options' );
		
		if( !isset( $options['menu_link_color'] ) ) $options['menu_link_color'] = 'rgba(211,90,0,1)';

			echo '<input type="text" id="menu-link-color-picker" class="color-picker" data-alpha-enabled="true" data-default-color="rgba(211,90,0,1)" name="munky-menu-menu_options[menu_link_color]" value="' . sanitize_text_field($options['menu_link_color']) . '"/>';

	}
	
	public function icon_background_color_callback() {
		
		$options = get_option( 'munky-menu-menu_options' );
		
		if( !isset( $options['icon_background_color'] ) ) $options['icon_background_color'] = 'rgba(232,232,232,1)';

			echo '<input type="text" id="icon-bgd-color-picker" class="color-picker" data-alpha-enabled="true" data-default-color="rgba(232,232,232,1)" name="munky-menu-menu_options[icon_background_color]" value="' . sanitize_text_field($options['icon_background_color']) . '"/>';

	}
	
	public function icon_color_callback() {
		
		$options = get_option( 'munky-menu-menu_options' );
		
		if( !isset( $options['icon_color'] ) ) $options['icon_color'] = 'rgba(102,102,102,1)';

			echo '<input type="text" id="icon-color-picker" class="color-picker" data-alpha-enabled="true" data-default-color="rgba(102,102,102,1)" name="munky-menu-menu_options[icon_color]" value="' . sanitize_text_field($options['icon_color']) . '"/>';

	}

	public function cta_callback() {

		$color_options = get_option( 'munky-menu-branding_options' );
		$options = get_option( 'munky-menu-menu_options' );
		
		if( !isset( $options['cta_icon_one'] ) ) $options['cta_icon_one'] = 'fa-home';
		if( !isset( $options['cta_icon_two'] ) ) $options['cta_icon_two'] = 'fa-envelope';
		if( !isset( $options['cta_icon_three'] ) ) $options['cta_icon_three'] = 'fa-shopping-basket';

		if( !isset( $options['cta_title_one'] ) ) $options['cta_title_one'] = 'Home';
		if( !isset( $options['cta_title_two'] ) ) $options['cta_title_two'] = 'Contact';
		if( !isset( $options['cta_title_three'] ) ) $options['cta_title_three'] = 'Basket';
		
		if( !isset( $options['cta_url_one'] ) ) $options['cta_url_one'] = '/';
		if( !isset( $options['cta_url_two'] ) ) $options['cta_url_two'] = '#';
		if( !isset( $options['cta_url_three'] ) ) $options['cta_url_three'] = '#';

		$html = '<span style="display: inline-grid; text-align: center; font-weight: 700;">Example';
		$html .=	'<label id="cta_icon_example" style="display: inline-grid; text-align: center; font-size: 2rem; line-height: 50px; color: ' . $color_options['brand_color'] . ';" class="cta-icon fas fa-icons" value="fas fa-icons"/>';
		$html .=	'<input readonly type="text" style="text-align: center; width: 150px; font-family: Arial; font-size: 10px;" class="cta-char fas fa-icons" name="munky-menu-menu_options[cta_icon_example]" value="Font Awesome Class">';
		$html .=	'<input readonly type="text" style="text-align: center; width: 150px; font-family: Arial;" class="cta-title cta-title-one" name="munky-menu-menu_options[cta_title_example]" value="Button Title">';
		$html .=	'<input readonly type="text" style="text-align: center; width: 150px; font-family: Arial;" class="cta-url cta-url-one" name="munky-menu-menu_options[cta_url_example]" value="Target URL"></label>';
		$html .= '</span> ';		
		$html .= '<span id="button-one" style="display: inline-grid; text-align: center; font-weight: 700;">Button One';
		$html .= '<span id="cta_icon_one" style="display: inline-grid; text-align: center; font-size: 2rem; line-height: 50px; min-height: 50px; color: ' . $color_options['brand_color'] . ';" class="cta-icon fas ' . $options['cta_icon_one'] . '" value=""/></span>';
		$html .=	'<input type="text" id="cta_char_one" style="text-align: center; width: 150px; font-family: Arial; font-size: 10px;" class="cta-char fas ' . $options['cta_icon_one'] . '" name="munky-menu-menu_options[cta_icon_one]" value="' . $options['cta_icon_one'] . '">';
		$html .=	'<input type="text" style="text-align: center; width: 150px; font-family: Arial;" class="cta-title cta-title-one" name="munky-menu-menu_options[cta_title_one]" value="' . $options['cta_title_one'] . '">';
		$html .=	'<input type="text" style="text-align: center; width: 150px; font-family: Arial;" class="cta-url cta-url-one" name="munky-menu-menu_options[cta_url_one]" value="' . sanitize_url( $options['cta_url_one']) . '">';
		$html .= '</span> ';
		$html .= '<span id="button-two" style="display: inline-grid; text-align: center; font-weight: 700;">Button Two';
		$html .= '<span id="cta_icon_two" style="display: inline-grid; text-align: center; font-size: 2rem; line-height: 50px; min-height: 50px; color: ' . $color_options['brand_color'] . ';" class="cta-icon fas ' . $options['cta_icon_two'] . '" value=""/></span>';
		$html .=	'<input type="text" id="cta_char_two" style="text-align: center; width: 150px; font-family: Arial; font-size: 10px;" class="cta-char fas ' . $options['cta_icon_two'] . '" name="munky-menu-menu_options[cta_icon_two]" value="' . $options['cta_icon_two'] . '">';
		$html .=	'<input type="text" style="text-align: center; width: 150px; font-family: Arial;" class="cta-title cta-title-two" name="munky-menu-menu_options[cta_title_two]" value="' . $options['cta_title_two'] . '">';
		$html .=	'<input type="text" style="text-align: center; width: 150px; font-family: Arial;" class="cta-url cta-url-two" name="munky-menu-menu_options[cta_url_two]" value="' . sanitize_url( $options['cta_url_two']) . '">';
		$html .= '</span> ';
		$html .= '<span id="button-three" style="display: inline-grid; text-align: center; font-weight: 700;">Button Three';
		$html .= '<span id="cta_icon_three" style="display: inline-grid; text-align: center; font-size: 2rem; line-height: 50px; min-height: 50px; color: ' . $color_options['brand_color'] . ';" class="cta-icon fas ' . $options['cta_icon_three'] . '" value=""/></span>';
		$html .=	'<input type="text" id="cta_char_three" style="text-align: center; width: 150px; font-family: Arial; font-size: 10px;" class="cta-char fas ' . $options['cta_icon_three'] . '" name="munky-menu-menu_options[cta_icon_three]" value="' . $options['cta_icon_three'] . '">';
		$html .=	'<input type="text" style="text-align: center; width: 150px; font-family: Arial;" class="cta-title cta-title-three" name="munky-menu-menu_options[cta_title_three]" value="' . $options['cta_title_three'] . '">';
		$html .=	'<input type="text" style="text-align: center; width: 150px; font-family: Arial;" class="cta-url cta-url-three" name="munky-menu-menu_options[cta_url_three]" value="' . sanitize_url( $options['cta_url_three']) . '">';
		$html .= '</span>';
		$html .= '<p>For an internal Call-to-Action link, e.g. a contact page at <em>https://my-site.com/contact</em> you can simply enter /contact/ in the Target URL box.</p>';
		$html .= '<p>To connect to an external link with Call-to-Action just enter the full URL of the target site/page.</p>';
		$html .= '<p>You can also enter an email address by using prefix mailto: e.g. <em>mailto:someone@someplace.com</em>.</p>';

		echo $html;

	} // end cta_callback

	public function support_usage_callback() {

		$options = get_option( 'munky-menu-support_options' );

		// Render the output
		
		$html = 'The easiest way to use Munky Mobile Menu is by adding a new Text Widget (footer, sidebar, etc.) and adding the shortcode \'[munky-mobile-menu]\' into it.';
		$html .= ' ';
		$html .= '<p>Alternatively, you can insert the below code into your theme\'s footer or, preferably, child theme\'s footer.</p>';
		$html .= ' ';
		$html .= '<figure>';
		$html .=	'<ol class="code">';
		$html .=		'<li></li>';
		$html .=		'<li></li>';
		$html .=		'<li></li>';
		$html .=		'<li></li>';
		$html .=		'<li></li>';
		$html .=		'<li></li>';
		$html .=	'</ol>';
		$html .=	'<pre>';
		$html .=		'<code>&lt;?php'."\n";
		$html .=		"\t".'if (function_exists(\'run_munky_mm\')) {'."\n";
		$html .=			"\t\t".'echo do_shortcode(\'[munky-mobile-menu]\');'."\n";
		$html .=		"\t".'} else {'."\n";
		$html .=		"\t".'}'."\n";
		$html .=		'?&gt;';
		$html .=		'</code>';
		$html .=	'</pre>';
		$html .= '</figure>';
		
		echo $html;

	} // end support_usage_callback

	public function support_faq_callback() {

		$options = get_option( 'munky-menu-support_options' );
		
		// Render the output

		// Can I use my own custom font in the Menu Header Font field?
		$html = '<details>';
		$html .=	'<summary style="font-weight: 700;">Can I use my own custom font in the Menu Header Font Field?</summary>';
		$html .=	'<div>';
		$html .=	'<p style="margin-top: 20px;">Yes. You can add multiple fonts to the Menu Header Font list if you want.</p>';
		$html .=	'<p>To add additional fonts do the following: -</p>';
		$html .=	'<ol>';
		$html .=		'<li>Navigate your way to your theme/child theme folder.</li>';
		$html .=		'<li>Inside your theme/child theme folder create a new folder and name it "<em>munky-mm</em>"</li>';
		$html .=	'</ol>';
		$html .=	' ';
		$html .=	'<p>Now, we\'re going to create two new files, "<em>mmm-custom-font.css</em>" and "<em>mmm-custom-font.json</em>".</p>';
		$html .=	'</div>';
		$html .=	'<div>';
		$html .=	'<details>';
		$html .=		'<summary style="font-size: 1rem; margin: 20px 0 0 20px;">mmm-custom-font.css</summary>';
		$html .=		'</br>';
		$html .=		'Purpose: "<em>mmm-custom-font.css</em>" allows us to display the font style as intended on the Munky Mobile Menu header.';
		$html .=		'<ol>';
		$html .=			'<li>Open the text editor of your choice (e.g. notepad). I recommend <a href="https://notepad-plus-plus.org/downloads/" target="_blank" rel="noopener">Notepad++</a>.</li>';
		$html .=			'<li>Use one of the following methods to enter font information in your text editor.</li>';
		$html .=		'</ol>';
		$html .=		'<h3><strong>The @import method</strong></h3>';
		$html .=		'<p>Used to obtain font CSS information from remote sources (e.g. Google Fonts<strong style="color: red;">*</strong>).';
		$html .=		'</br>Let\'s say we want to use the font "Josefin Sans" by way of Google Fonts. We would enter the following line in our text editor.</p>';
		$html .=		'<figure>';
		$html .=			'<ol class="code">';
		$html .=				'<li></li>';
		$html .=			'</ol>';
		$html .=			'<pre>';
		$html .=				'<code>';
		$html .=				'@import url(\'https://fonts.googleapis.com/css2?family=Josefin+Sans&display=swap\');';
		$html .=				'</code>';
		$html .=			'</pre>';
		$html .=		'</figure>';
		$html .=		'<p>We then save the file as "<em>mmm-custom-font.css</em>" in the "<em>munky-mm</em>" folder we created earlier.</p>';
		$html .=		'<p>If we wanted to import additional font styles from Google Fonts we can stack them into our @import url.</p>';
		$html .= 		'<figure>';
		$html .=			'<ol class="code">';
		$html .=				'<li></li>';
		$html .=			'</ol>';
		$html .=			'<pre>';
		$html .=				'<code>';
		$html .=				'@import url(\'https://fonts.googleapis.com/css2?family=Josefin+Sans&<em><strong>family=Roboto&family=Open+Sans&</strong></em>display=swap\');';
		$html .=				'</code>';
		$html .=			'</pre>';
		$html .=		'</figure>';
		$html .=		'<h3><strong>The @font-face method</strong></h3>';
		$html .=		'<p>We use this method to assign a simplified name for a local font.';
		$html .=		'</br>Again we want to use the font "Josefin Sans" except this time we have the font file "JosefinSans-Regular.ttf" on our computer.</p>';
		$html .=		'<ol>';
		$html .=			'<li>Copy the font file "JosefinSans-Regular.ttf" into the "<em>munky-mm</em>" folder we created earlier.</li>';
		$html .=			'<li>Enter the following lines in our text editor. This allows us to refer to our font as "Josefin Sans".</li>';
		$html .=		'</ol>';
		$html .=	'<figure>';
		$html .=		'<ol class="code">';
		$html .=			'<li></li>';
		$html .=			'<li></li>';
		$html .=			'<li></li>';
		$html .=		'</ol>';
		$html .=		'<pre>';
		$html .=			'<code>';
		$html .=				'@font-face {'."\n";
		$html .=				"\t".'font-family: \'Josefin Sans\';'."\n";
		$html .=				"\t".'src: url(\'JosefinSans-Regular.otf\');'."\n";
		$html .=				'}'."\n";
		$html .=			'</code>';
		$html .=		'</pre>';
		$html .=	'</figure>';
		$html .=	'<ol start="3">';
		$html .=		'<li>Save the file as "<em>mmm-custom-font.css</em>" in the "<em>munky-mm</em>" folder.</li>';
		$html .=	'</ol>';
		$html .=	'<p><strong style="color: red;">*EU/European site owners, please note, Google Fonts, and possibly other font streaming services, are considered to be GDPR non-compliant.</strong></p>';
		$html .=	'<p><strong style="color: red;">Use at your own risk.</strong> It is recommended to download the font and install locally using the @font-face method.</p>';
		$html .=	'</details>';
		$html .=	'</div>';
		$html .=	'<div>';
		$html .=	'<details>';
		$html .=		'<summary style="font-size: 1rem; margin: 20px 0 0 20px;">mmm-custom-font.json</summary>';
		$html .=		'</br>';
		$html .=		'Purpose: "<em>mmm-custom-font.json</em>" populates the Menu Header Font list with your custom font(s) and provides font category.';
		$html .=		'</br></br>';
		$html .=		'<p>If you are using Google Fonts and don\'t know the font family and\or category continue reading, otherwise, if you know your font family name and category you can skip to step 9.</p>';
		$html .=		'<ol>';
		$html .=			'<li>Open your text editor.</li>';
		$html .=			'<li>Visit <a href="https://developers.google.com/fonts/docs/developer_api" target="_blank" rel="noopener">https://developers.google.com/fonts/docs/developer_api</a></li>';
		$html .=			'<li>In the right-hand pane entitled "Try this method" click the expand <span style="content: \f065;" class="fas fa-lg fa-expand"></span> icon.</li>';
		$html .=			'<li>Under "Request parameters" in the "sort" list, select "ALPHA".</li>';
		$html .=			'<li>Click the "EXECUTE" button.</li>';
		$html .=			'<li>You should see a "200 OK" response box with a green header. Scroll down until you see the information for "Josefin Sans".</li>';
		$html .=			'<li>There\'s a lot of information because it accounts for each variation of this font. We\'re only interested in the regular version.</li>';
		$html .=			'<li>Note the "family" and "category" information for "Josefin Sans" ready to input into your text editor.</li>';
		$html .=			'<li>Add "family" and "category" into our JSON as displayed below.</li>';
		$html .=		'</ol>';
		$html .=		'<figure>';
		$html .=			'<ol class="code">';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=			'</ol>';
		$html .=			'<pre>';
		$html .=				'<code>';
		$html .=				'{'."\n";
		$html .=					"\t".'"items": ['."\n";
		$html .=						"\t"."\t".'{'."\n";
		$html .=							"\t"."\t"."\t".'"family": "Josefin Sans",'."\n";
		$html .=							"\t"."\t"."\t".'"category": "sans-serif"'."\n";
		$html .=						"\t"."\t".'},'."\n";
		$html .=					"\t".']'."\n";
		$html .=				'}'."\n";
		$html .=				'</code>';
		$html .=			'</pre>';
		$html .=		'</figure>';
		$html .=		'<ol start="10">';
		$html .=			'<li>Save the file as "<em>mmm-custom-font.json</em>" in the "<em>munky-mm</em>" folder.</li>';
		$html .=			'<li>Assuming you have your "<em>mmm-custom-font.css</em>" in place alongside your "<em>mmm-custom-font.json</em>" you should now be able to refresh the page and select your font from the Branding Options page.</li>';
		$html .=		'</ol>';
		$html .=		'<p>An example of multiple fonts.</p>';
		$html .=		'<figure>';
		$html .=			'<ol class="code">';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=				'<li></li>';
		$html .=			'</ol>';
		$html .=			'<pre>';
		$html .=				'<code>';
		$html .=				'{'."\n";
		$html .=					"\t".'"items": ['."\n";
		$html .=						"\t"."\t".'{'."\n";
		$html .=							"\t"."\t"."\t".'"family": "Josefin Sans",'."\n";
		$html .=							"\t"."\t"."\t".'"category": "sans-serif",'."\n";
		$html .=						"\t"."\t".'},'."\n";
		$html .=						"\t"."\t".'{'."\n";
		$html .=							"\t"."\t"."\t".'"family": "Another Font",'."\n";
		$html .=							"\t"."\t"."\t".'"category": "cursive",'."\n";
		$html .=						"\t"."\t".'},'."\n";
		$html .=					"\t".']'."\n";
		$html .=				'}'."\n";
		$html .=				'</code>';
		$html .=			'</pre>';
		$html .=		'</figure>';
		$html .=		'</br>';
		$html .=		'<p>Don\'t forget...';
		$html .=		'<ol>';
		$html .=			'<li>Copy any local fonts to the "<em>munky-mm</em>" folder.</li>';
		$html .=			'<li>Add the CSS entries for each additional font. Stack @import fonts and a separate @font-face for each local font.</li>';
		$html .=			'<li>Include the correct category for your fonts (cursive, sans-serif, script, serif, etc.)</li>';
		$html .=			'<li>Files should be saved in UTF-8 format. In Notepad++ you can select this from the Encoding menu. In Windows Notepad you\'ll find this in the Encoding menu in the Save dialog.</li>';
		$html .=		'</ol>';
		$html .=	'</details>';
		$html .=	'</div>';
		$html .= '</details>';

		$html .= '</br>';
				
		// How do I change the colour of the Call-to-Action icons?
		$html .= '<details>';
		$html .=	'<summary style="font-weight: 700;">How do I change the colour of the Call-to-Action icons?</summary>';
		$html .=	'<div>';
		$html .=	'<p style="margin-top: 20px;">The Call-to-Action icons are assigned Brand Color</p>';
		$html .=	'<p>You can change the Brand Color in the Branding Options section.</p>';
		$html .=	'</br>';
		$html .=	'<p>Alternatively, you can assign a colour to the Call-to-Action buttons separately in Appearance>Additional CSS, or in your theme/child theme stylesheet.</p>';
		$html .=	'<figure>';
		$html .=		'<ol class="code">';
		$html .=			'<li></li>';
		$html .=			'<li></li>';
		$html .=			'<li></li>';
		$html .=		'</ol>';
		$html .=		'<pre>';
		$html .=			'<code>';
		$html .=			'a.cta-color {'."\n";
		$html .=				"\t".'color: COLOR-NAME or HEX-VALUE or RGB(A)-VALUE;'."\n";
		$html .=			'}'."\n";
		$html .=			'</code>';
		$html .=		'</pre>';
		$html .=	'</figure>';
		$html .=	'</div>';
		$html .= '</details>';

		echo $html;

	} // end support_faq_callback

	public function support_info_callback() {

		$options = get_option( 'munky-menu-support_options' );

		// Render the output
		echo 'Website: <a href="https://www.heymunky.co.uk" target="_blank" rel="noopener">https://www.heymunky.co.uk</a>';
		echo '</br>';
		echo 'Contact: <a href="https://www.heymunky.co.uk/contact/" target="_blank" rel="noopener">https://www.heymunky.co.uk/contact/</a>';

	} // end support_info_callback

	public function validate_menu_options( $input ) {

		// Create our array for storing the validated options
		$output = array();

		// Loop through each of the incoming options
		foreach( $input as $key => $value ) {

			// Check to see if the current option has a value. If so, process it.
			if( isset( $input[$key] ) ) {

				// Strip all HTML and PHP tags and properly handle quoted strings
				$output[$key] = strip_tags( stripslashes( $input[ $key ] ) );

			} // end if

		} // end foreach

		// Return the array processing any additional functions filtered by this action
		return apply_filters( 'validate_menu_options', $output, $input );

	} // end validate_input_examples

}
?>