<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://heymunky.co.uk
 * @since             1.0.0
 * @package           Munky_Mm
 *
 * @wordpress-plugin
 * Plugin Name:       Munky Mobile Menu
 * Plugin URI:        https://heymunky.co.uk
 * Description:       A mobile menu with search and call-to-action.
 * Version:           1.0.0
 * Author:            Munky
 * Author URI:        https://heymunky.co.uk
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       munky-mm
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'MUNKY_MM_VERSION', '1.0.0' );

function add_plugin_settings_link( $settingLink ) {
    $settingLink[] = '<a href="' .admin_url( 'admin.php?page=munky-menu-settings' ) .'">' . __('Settings') . '</a>';
    return $settingLink;
}
add_filter('plugin_action_links_'.plugin_basename(__FILE__), 'add_plugin_settings_link');

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-munky-mm-activator.php
 */
function activate_munky_mm() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-munky-mm-activator.php';
	Munky_Mm_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-munky-mm-deactivator.php
 */
function deactivate_munky_mm() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-munky-mm-deactivator.php';
	Munky_Mm_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_munky_mm' );
register_deactivation_hook( __FILE__, 'deactivate_munky_mm' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-munky-mm.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_munky_mm() {

	$plugin = new Munky_Mm();
	$plugin->run();

}
run_munky_mm();
