<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://heymunky.co.uk
 * @since      1.0.0
 *
 * @package    Munky_Mm
 * @subpackage Munky_Mm/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Munky_Mm
 * @subpackage Munky_Mm/public
 * @author     Munky <munky@heymunky.co.uk>
 */
class Munky_Mm_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
				
		$custom_font_path = get_stylesheet_directory() . '/munky-mm/';
		$custom_font_css = get_stylesheet_directory_uri() . '/munky-mm/mmm-custom-font.css';

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Munky_Mm_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Munky_Mm_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/munky-mm-public.css', array(), $this->version, 'all' );
		//wp_enqueue_style( 'mmm-google-fonts','https://fonts.googleapis.com/css?family=Inter|Lato|Merriweather|Montserrat|Noto%20Sans|Open%20Sans|Playfair%20Display|Poppins|Raleway|Roboto|Roboto%20Slab');
		wp_enqueue_style('font-awesome','https://use.fontawesome.com/releases/v6.2.1/css/all.css');
		
		clearstatcache(); //file_exists is cachable. Clear the cache before calling it.
		if ( file_exists( $custom_font_path )) {
			wp_enqueue_style( 'mmm-custom-font',$custom_font_css );
		} else {
			 
		}

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Munky_Mm_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Munky_Mm_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/munky-mm-public.js', array( 'jquery' ), $this->version, true );

	}
	
	public function register_shortcodes() {
		add_shortcode( 'munky-mobile-menu', array( $this, 'munky_mm_shortcode') );
	}
		
	function munky_mm_shortcode() {
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/munky-mm-public-display.php';
	}

}
